Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorClément Foucault <foucault.clem@gmail.com>2018-11-23 20:03:08 +0300
committerClément Foucault <foucault.clem@gmail.com>2018-11-23 20:03:18 +0300
commit0d0c79e879fe0c7bf1f1d47968c11578a05db7cf (patch)
treeeba24afc1bb78f24f5a36da07f465fea7b6e6422 /source/blender/draw
parentff6e61f09ab2c86edef651fc38c242f5fefdd569 (diff)
DRW: Make non Mesh object wire show in edit mode
Diffstat (limited to 'source/blender/draw')
-rw-r--r--source/blender/draw/modes/overlay_mode.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/draw/modes/overlay_mode.c b/source/blender/draw/modes/overlay_mode.c
index 2409d4033e0..460b3d4240a 100644
--- a/source/blender/draw/modes/overlay_mode.c
+++ b/source/blender/draw/modes/overlay_mode.c
@@ -251,8 +251,8 @@ static void overlay_cache_populate(void *vedata, Object *ob)
(ob->dtx & OB_DRAWWIRE) ||
(ob->dt == OB_WIRE))
{
- /* Don't do that in edit mode. */
- if ((ob != draw_ctx->object_edit) && !BKE_object_is_in_editmode(ob)) {
+ /* Don't do that in edit Mesh mode. */
+ if (((ob != draw_ctx->object_edit) && !BKE_object_is_in_editmode(ob)) || ob->type != OB_MESH) {
const bool is_active = (ob == draw_ctx->obact);
const bool is_sculpt_mode = is_active && (draw_ctx->object_mode & OB_MODE_SCULPT) != 0;
const bool all_wires = (stl->g_data->overlay.wireframe_threshold == 1.0f) ||